==> vst3sdk-docs-3.7.14_build_55-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/base/group__pluginGUI.js <==
var group__pluginGUI =
[
    [ "Platform UI Types", "group__platformUIType.html", null ],
    [ "ViewRect", "structSteinberg_1_1ViewRect.html", [
      [ "ViewRect", "structSteinberg_1_1ViewRect.html#afcdde0147792d1103d06537c37e59ef0", null ],
      [ "getWidth", "structSteinberg_1_1ViewRect.html#a8393748cd69f8fb3f27257f9e7f5900b", null ],
      [ "getHeight", "structSteinberg_1_1ViewRect.html#ae5ffb6f69df44efc559a8958a9da064c", null ],
      [ "left", "structSteinberg_1_1ViewRect.html#ae08ef45a841fb76eef2ed11f7f6661ad", null ],
      [ "top", "structSteinberg_1_1ViewRect.html#a5aea1a81a05b75bedc5d4c40373592d1", null ],
      [ "right", "structSteinberg_1_1ViewRect.html#a773c879226336b9859a3dec0a7f8e6ca", null ],
      [ "bottom", "structSteinberg_1_1ViewRect.html#a056cba400137ab9db43fdc7da2132a40", null ]
    ] ],
    [ "IPlugView", "classSteinberg_1_1IPlugView.html", [
      [ "isPlatformTypeSupported", "classSteinberg_1_1IPlugView.html#abcfa60e135807caa316f3915622d9488", null ],
      [ "attached", "classSteinberg_1_1IPlugView.html#a9fbc345c1e87f7e6210a8a49fdb96793", null ],
      [ "removed", "classSteinberg_1_1IPlugView.html#ad89d6c88074a716218e42805649d3591", null ],
      [ "onWheel", "classSteinberg_1_1IPlugView.html#a576b66ba9806bcecc3256110f5dd246a", null ],
      [ "onKeyDown", "classSteinberg_1_1IPlugView.html#a759b576f046e699c84dc07d579600b1b", null ],
      [ "onKeyUp", "classSteinberg_1_1IPlugView.html#ae726f4b3471ee2485a0bbb651cd35ff2", null ],
      [ "getSize", "classSteinberg_1_1IPlugView.html#ae4f7f751a5b75837f47ba19b29c53917", null ],
      [ "onSize", "classSteinberg_1_1IPlugView.html#a3e741e55c2c047a4cc10f102661f5654", null ],
      [ "onFocus", "classSteinberg_1_1IPlugView.html#abc80a2e0d25e151cbc2fabd1bd200683", null ],
      [ "setFrame", "classSteinberg_1_1IPlugView.html#ab0f059918bbf55ce110fc410240de423", null ],
      [ "canResize", "classSteinberg_1_1IPlugView.html#a07d7a22ae1ef493c4bb22c9411ae7ddf", null ],
      [ "checkSizeConstraint", "classSteinberg_1_1IPlugView.html#adc868253b8260f20a6764e338fecb7e1", null ]
    ] ],
    [ "IPlugFrame", "classSteinberg_1_1IPlugFrame.html", [
      [ "resizeView", "classSteinberg_1_1IPlugFrame.html#a94f218315acd695606fff41166294d56", null ]
    ] ],
    [ "IEventHandler", "classSteinberg_1_1Linux_1_1IEventHandler.html", [
      [ "onFDIsSet", "classSteinberg_1_1Linux_1_1IEventHandler.html#ac953714233e0c3af5f14e7ab8dfc68f5", null ]
    ] ],
    [ "ITimerHandler", "classSteinberg_1_1Linux_1_1ITimerHandler.html", [
      [ "onTimer", "classSteinberg_1_1Linux_1_1ITimerHandler.html#a90a0d24275b47109b29b50f80d95c8d5", null ]
    ] ],
    [ "IRunLoop", "classSteinberg_1_1Linux_1_1IRunLoop.html", [
      [ "registerEventHandler", "classSteinberg_1_1Linux_1_1IRunLoop.html#ae13eeed00dc375e958a4375fc29a6355", null ],
      [ "unregisterEventHandler", "classSteinberg_1_1Linux_1_1IRunLoop.html#a8aa17239995359c3ba6f120b041f4e7e", null ],
      [ "registerTimer", "classSteinberg_1_1Linux_1_1IRunLoop.html#aa9a7ecb89251432205aea8bc15e12c9a", null ],
      [ "unregisterTimer", "classSteinberg_1_1Linux_1_1IRunLoop.html#ae84103b4ac33ddbe1fec57d28e917618", null ]
    ] ],
    [ "IPlugViewContentScaleSupport", "classSteinberg_1_1IPlugViewContentScaleSupport.html", [
      [ "ScaleFactor", "classSteinberg_1_1IPlugViewContentScaleSupport.html#a75ec4b5d086d2af3733ac3775ab008d8", null ],
      [ "setContentScaleFactor", "classSteinberg_1_1IPlugViewContentScaleSupport.html#af5b0fea85beba3cdcfeb8de66779f478", null ]
    ] ]
];

==> vst3sdk-docs-3.8.0_build_66-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/base/group__pluginGUI.js <==
var group__pluginGUI =
[
    [ "Platform UI Types", "group__platformUIType.html", "group__platformUIType" ],
    [ "ViewRect", "structSteinberg_1_1ViewRect.html", [
      [ "ViewRect", "structSteinberg_1_1ViewRect.html#afcdde0147792d1103d06537c37e59ef0", null ],
      [ "getWidth", "structSteinberg_1_1ViewRect.html#a8393748cd69f8fb3f27257f9e7f5900b", null ],
      [ "getHeight", "structSteinberg_1_1ViewRect.html#ae5ffb6f69df44efc559a8958a9da064c", null ],
      [ "left", "structSteinberg_1_1ViewRect.html#ae08ef45a841fb76eef2ed11f7f6661ad", null ],
      [ "top", "structSteinberg_1_1ViewRect.html#a5aea1a81a05b75bedc5d4c40373592d1", null ],
      [ "right", "structSteinberg_1_1ViewRect.html#a773c879226336b9859a3dec0a7f8e6ca", null ],
      [ "bottom", "structSteinberg_1_1ViewRect.html#a056cba400137ab9db43fdc7da2132a40", null ]
    ] ],
    [ "IPlugView", "classSteinberg_1_1IPlugView.html", [
      [ "isPlatformTypeSupported", "classSteinberg_1_1IPlugView.html#abcfa60e135807caa316f3915622d9488", null ],
      [ "attached", "classSteinberg_1_1IPlugView.html#a9fbc345c1e87f7e6210a8a49fdb96793", null ],
      [ "removed", "classSteinberg_1_1IPlugView.html#ad89d6c88074a716218e42805649d3591", null ],
      [ "onWheel", "classSteinberg_1_1IPlugView.html#a576b66ba9806bcecc3256110f5dd246a", null ],
      [ "onKeyDown", "classSteinberg_1_1IPlugView.html#a759b576f046e699c84dc07d579600b1b", null ],
      [ "onKeyUp", "classSteinberg_1_1IPlugView.html#ae726f4b3471ee2485a0bbb651cd35ff2", null ],
      [ "getSize", "classSteinberg_1_1IPlugView.html#ae4f7f751a5b75837f47ba19b29c53917", null ],
      [ "onSize", "classSteinberg_1_1IPlugView.html#a3e741e55c2c047a4cc10f102661f5654", null ],
      [ "onFocus", "classSteinberg_1_1IPlugView.html#abc80a2e0d25e151cbc2fabd1bd200683", null ],
      [ "setFrame", "classSteinberg_1_1IPlugView.html#ab0f059918bbf55ce110fc410240de423", null ],
      [ "canResize", "classSteinberg_1_1IPlugView.html#a07d7a22ae1ef493c4bb22c9411ae7ddf", null ],
      [ "checkSizeConstraint", "classSteinberg_1_1IPlugView.html#adc868253b8260f20a6764e338fecb7e1", null ]
    ] ],
    [ "IPlugFrame", "classSteinberg_1_1IPlugFrame.html", [
      [ "resizeView", "classSteinberg_1_1IPlugFrame.html#a94f218315acd695606fff41166294d56", null ]
    ] ],
    [ "IEventHandler", "classSteinberg_1_1Linux_1_1IEventHandler.html", [
      [ "onFDIsSet", "classSteinberg_1_1Linux_1_1IEventHandler.html#ac953714233e0c3af5f14e7ab8dfc68f5", null ]
    ] ],
    [ "ITimerHandler", "classSteinberg_1_1Linux_1_1ITimerHandler.html", [
      [ "onTimer", "classSteinberg_1_1Linux_1_1ITimerHandler.html#a90a0d24275b47109b29b50f80d95c8d5", null ]
    ] ],
    [ "IRunLoop", "classSteinberg_1_1Linux_1_1IRunLoop.html", [
      [ "registerEventHandler", "classSteinberg_1_1Linux_1_1IRunLoop.html#ae13eeed00dc375e958a4375fc29a6355", null ],
      [ "unregisterEventHandler", "classSteinberg_1_1Linux_1_1IRunLoop.html#a8aa17239995359c3ba6f120b041f4e7e", null ],
      [ "registerTimer", "classSteinberg_1_1Linux_1_1IRunLoop.html#aa9a7ecb89251432205aea8bc15e12c9a", null ],
      [ "unregisterTimer", "classSteinberg_1_1Linux_1_1IRunLoop.html#ae84103b4ac33ddbe1fec57d28e917618", null ]
    ] ],
    [ "IPlugViewContentScaleSupport", "classSteinberg_1_1IPlugViewContentScaleSupport.html", [
      [ "ScaleFactor", "group__smtgtypedef.html#ga75ec4b5d086d2af3733ac3775ab008d8", null ],
      [ "setContentScaleFactor", "classSteinberg_1_1IPlugViewContentScaleSupport.html#af5b0fea85beba3cdcfeb8de66779f478", null ]
    ] ]
];
